@@ -148,8 +148,8 @@ public:
 
 public:
 
-    explicit AbstractMarkerTiler(QObject* const parent = 0);
-    virtual ~AbstractMarkerTiler();
+    explicit AbstractMarkerTiler(QObject* const parent = nullptr);
+    ~AbstractMarkerTiler() override;
 
     void tileDeleteChildren(Tile* const tile);
     void tileDelete(Tile* const tile);
